@@ -112,9 +112,15 @@ class Shape(object):
         return self._shape_data.get('x-no-paramfile', False)
 
     @CachedProperty
-    def is_undocumented(self):
+    def is_deprecated(self):
         return self._shape_data.get('x-deprecated', False)
 
+    @CachedProperty
+    def form_factors(self):
+        if "x-form-factors" in self._shape_data:
+            return self._shape_data['x-form-factors'].split(',')
+        return None
+
     def _get_shape(self, name, shape_data):
         if REF_KEY in shape_data:
             # Reference value type
@@ -235,6 +241,10 @@ class OperationModel(object):
     def service_model(self):
         return self._service_model
 
+    @CachedProperty
+    def summary(self):
+        return self._operation_data["summary"]
+
     @CachedProperty
     def documentation(self):
         return self._operation_data["description"]
@@ -282,6 +292,22 @@ class OperationModel(object):
             return int(self._operation_data.get("x-paging-default-max-items"))
         return None
 
+    @CachedProperty
+    def is_deprecated(self):
+        return self._operation_data.get('x-deprecated', False)
+
+    @CachedProperty
+    def form_factors(self):
+        if "x-form-factors" in self._operation_data:
+            return self._operation_data['x-form-factors'].split(',')
+        return None
+
+    @CachedProperty
+    def extensions(self):
+        if "x-extensions" in self._operation_data:
+            return self._operation_data['x-extensions'].split(',')
+        return None
+
     @CachedProperty
     def input_shape(self):
         return self._service_model.resolve_shape_ref(
@@ -289,8 +315,12 @@ class OperationModel(object):
 
     @CachedProperty
     def output_shape(self):
-        return self._service_model.resolve_shape_ref(
-            "output", self._operation_data['responses'][200]['schema'][REF_KEY])
+        if '200' in self._operation_data['responses']:
+            return self._service_model.resolve_shape_ref(
+                "output", self._operation_data['responses']['200']['schema'][REF_KEY])
+        else:
+            return self._service_model.resolve_shape_ref(
+                "output", self._operation_data['responses'][200]['schema'][REF_KEY])
 
 
 class ServiceModel(object):
@@ -305,6 +335,14 @@ class ServiceModel(object):
     def service_name(self):
         return self._service_name
 
+    @CachedProperty
+    def service_version(self):
+        return self._service_data["info"]["version"]
+
+    @CachedProperty
+    def service_title(self):
+        return self._service_data["info"]["title"]
+
     @CachedProperty
     def documentation(self):
         return self._service_data["info"]["description"]
@@ -320,6 +358,14 @@ class ServiceModel(object):
                                           operation_name,
                                           http_method,
                                           request_uri)
+                if operation_data.get("x-alt-operation-id", None) == operation_name:
+                    operation_data = operation_data.copy()
+                    operation_data["x-deprecated"] = True
+                    return OperationModel(operation_data,
+                                          self,
+                                          operation_name,
+                                          http_method,
+                                          request_uri)
         raise OperationNotFoundError(operation_name)
 
     @CachedProperty
@@ -327,8 +373,10 @@ class ServiceModel(object):
         operation_names = []
         for path in self._service_data["paths"]:
             for operation in self._service_data["paths"][path]:
-                operation_names.append(
-                    self._service_data["paths"][path][operation]["operationId"])
+                operation_data = self._service_data["paths"][path][operation]
+                operation_names.append(operation_data["operationId"])
+                if "x-alt-operation-id" in operation_data:
+                    operation_names.append(operation_data["x-alt-operation-id"])
         return operation_names
 
     def resolve_shape_ref(self, name, shape_ref):
@@ -346,6 +394,10 @@ class ServiceModel(object):
     def products(self):
         return self._service_data.get("x-products", "ALTUS").split(',')
 
+    @CachedProperty
+    def form_factors(self):
+        return self._service_data.get("x-form-factors", "public").split(',')
+
 
 class DenormalizedStructureBuilder(object):
     """Build a StructureShape from a denormalized model.
